package com.admin.major.service.impl;

import java.util.List;
import com.admin.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.admin.common.utils.SecurityUtils;
import com.admin.common.utils.uuid.IdUtils;
import com.admin.major.mapper.NoticeMapper;
import com.admin.major.domain.Notice;
import com.admin.major.service.INoticeService;

/**
 * 消息管理Service业务层处理
 * 
 * @author zewei
 * @date 2022-03-28
 */
@Service
public class NoticeServiceImpl implements INoticeService 
{
    @Autowired
    private NoticeMapper noticeMapper;

    /**
     * 查询消息管理
     * 
     * @param noticeId 消息管理主键
     * @return 消息管理
     */
    @Override
    public Notice selectNoticeByNoticeId(String noticeId)
    {
        return noticeMapper.selectNoticeByNoticeId(noticeId);
    }

    /**
     * 查询消息管理列表
     * 
     * @param notice 消息管理
     * @return 消息管理
     */
    @Override
    public List<Notice> selectNoticeList(Notice notice)
    {
        return noticeMapper.selectNoticeList(notice);
    }



    /**
     * 查询消息管理
     *
     * @param notice 消息管理
     * @return 消息管理
     */
    @Override
    public Notice selectOneNotice(Notice notice)
    {
        return noticeMapper.selectNoticeList(notice)
                .stream()
                .findFirst()
                .orElse(null);
    }

    /**
     * 新增消息管理
     *
     * @param notice 消息管理
     * @return 结果
     */

    @Override
    public int insertNotice(Notice notice)
    {
        notice.setNoticeId(IdUtils.simpleUUID());
        notice.setCreateTime(DateUtils.getNowDate());
        notice.setCreateUserId(SecurityUtils.getUserId());
        notice.setUpdateUserId(SecurityUtils.getUserId());
        return noticeMapper.insertNotice(notice);
    }

    /**
     * 修改消息管理
     * 
     * @param notice 消息管理
     * @return 结果
     */
    @Override
    public int updateNotice(Notice notice)
    {
        notice.setUpdateTime(DateUtils.getNowDate());
        notice.setUpdateUserId(SecurityUtils.getUserId());
        return noticeMapper.updateNotice(notice);
    }

    /**
     * 批量删除消息管理
     * 
     * @param noticeIds 需要删除的消息管理主键
     * @return 结果
     */
    @Override
    public int deleteNoticeByNoticeIds(String[] noticeIds)
    {
        return noticeMapper.deleteNoticeByNoticeIds(noticeIds);
    }

    /**
     * 删除消息管理信息
     * 
     * @param noticeId 消息管理主键
     * @return 结果
     */
    @Override
    public int deleteNoticeByNoticeId(String noticeId)
    {
        return noticeMapper.deleteNoticeByNoticeId(noticeId);
    }
}
